@@ -16,11 +16,13 @@ class StorageWriter:
     Attributes
     ----------
     credentials : Optional[str]
-        default: None
+        default : None
+
         The credentials to use for the selected storage location.
 
-        Note: If the storage location is AWS S3, the credentials file must be in the .env format and
-        If the storage location is Google Storage, the credentials file must be in the .json format.
+            Note:
+            If the storage location is AWS S3, the credentials file must be in the .env format and
+            If the storage location is Google Storage, the credentials file must be in the .json format.
     """
 
     credentials: Optional[str] = field(default=None)
